# Employers
A list of employers for the selected person. For more details on how to add/delete employers see section "Buttons".

## Columns:
Each column title has three lines on the right if you hover over it. Click on them to show options for that column. The second tab of the options menu will allow you to filter the column, the third to completely hide entire columns. Click on anywhere else on the column to order it, cycling between ascending, descending and no ordering. Hold shift while clicking to order multiple columns with individual weights.

### Name:
The employer's first and last name.

### Position in Company:
The person's position within its company. Positions can be added, edited and deleted by managers under CRM > Administration > Company Positions.

### City:
The city where the employer is located. Hover over the name to display the detailed address.

### Type:
The company type of the employer. Company types can be added, edited and deleted by managers under CRM > Administration > Company Types.

### Tier:
The employer's tier. Tiers range from 1 to 5 and are automatically computed.

### Status:
The employer's status. Company statuses can be added, edited and deleted by managers under CRM > Administration > Customer Status.

### Primary Relationship Manager:
Displays the primary relationship manager of the employer. Hover over the name to display more information about the person.

## Legend:
Click on the legend to filter for primary employers.

## Buttons:
To add employers to the person the company needs to already exist in the database. Use the custom button labeled "New Company" at the top of the list if you need to create a new company and return to this view. Now you are able to add the company to the person by pressing the green plus button. Deleting an employer (but not the company) can be achieved by using the trash button at the end of the row if the company is a) not the person's primary employer or b) the person's only employer. If the person has several employers you need to first make one of the other employers primary to be able to see the delete button. The button below the trash icon shwowing a group of persons can be used to modify the relationship, e.g. make it primary or modify the person's position within their employer.

## Filters:

### No Relationship Manager:
Filter employers by if they have a relationship manager.

### No Activity:
Filter employees with no activity for x amount of time.

## Search Field:
Typing in the search field allows to filter the employers by name.
